@@ -49,8 +49,5 @@ class ConnectionResource(Resource):
     def update(self, _id: str, opts: ConnectionUpdateOpts) -> Connection:
         return super(ConnectionResource, self)._update_with_id(_id, opts)
 
-    def get_accounts(self, _id: str) -> List[Account]:
-        return super(ConnectionResource, self)._get_with_sub_path('{_id}/accounts'.format(_id=_id))
-
     def get_public_account_tokens(self, _id: str) -> List[str]:
         return super(ConnectionResource, self)._get_with_sub_path('{_id}/public_account_tokens'.format(_id=_id))
